/**
 * importing components or modules
 */
import { json, select, tree, hierarchy, linkVertical} from 'd3';

const HeaderText = "My large Family"
const svg = select('svg'); //initialize a svg

//the following are dimensions and margins of svg
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const margin = {top: 40, bottom: 90, right: 150, left: 80};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree().size([innerHeight + 300, innerWidth - 100]); //initialize a
																																		// tree with its layout

//initialize a group element and it will be used to group different elements together
const g = svg
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);
svg.append('text').attr('y',40).attr('x',300).text(HeaderText);;
  
//read the json data and assign the data to roots and other nodes and create links
// between nodes
json('data.json')
  .then(data => {
  const root = hierarchy(data);
  const links = treeLayout(root).links();
  const linkPathGenerator = linkVertical()
    .x(d => d.x)
    .y(d => d.y);
    
// assign the link data to path to create a path and append to the group
g.selectAll('path').data(links)
   .enter().append('path')
   .attr('d', linkPathGenerator);

// assign the text data to the different nodes and append to the group
g.selectAll('text').data(root.descendants())
   .enter().append('text')
   .attr('x', d => d.x)
   .attr('y', d => d.y)
   .attr('text-anchor', 'middle')
   .style('fill', d => d.data.data.color)
   .text(d => d.data.data.id)
});